This directory contains an example Python package that uses Bravado and
bravado-types to integrate with the Swagger Petstore.  The files in this
directory are used as an end-to-end integration test of bravado-types.

To run the tests, run `tox` in this directory or `tox -eintegration` from the
parent directory.
